SHORTCACHE_MAPPING = {
    'log_type': './td[1]/img[1]/attribute::title',
    'found_date': './td[3]/text()',
    'type': './td[4]//a[1]/img[1]/attribute::title',
    'title': './td[4]//a[2]//text()',
    'region': './td[5]//text()',
    'detail_link': './td[4]//a[1]/attribute::href'
}

GEOCACHE_MAPPING = {
    'geocode': '//*[@id="ctl00_ContentBody_CoordInfoLinkControl1_uxCoordInfoCode"]//text()',
    'title': '//*[@id="ctl00_ContentBody_CacheName"]//text()',
    'owner': '//*[@id="ctl00_ContentBody_mcd1"]/a//text()',
    'difficulty': '//*[@id="ctl00_ContentBody_uxLegendScale"]/img/attribute::src',
    'terrain': '//*[@id="ctl00_ContentBody_Localize12"]/img/attribute::src',
    'size': '//*[@id="ctl00_ContentBody_size"]/p/span/img/attribute::src',
    'coordinates': '//*[@id="uxLatLon"]//text()',
    'archived': 'boolean(//*[@id="divContentMain"]/div[3]/ul/li[contains(text(), \'This cache has been archived\')])'
}

SOUVENIR_ENTRY = '//*[@id="divContentMain"]/div[@class="ProfileSouvenirsList"]/div[starts-with(@id, "souvenir")]'
SHORT_SOUVENIR_MAPPING = {
    'title': 'a[1]/attribute::title',
    'image_url': 'a[1]/img[1]/attribute::src',
    'aquired_on': './text()[3]',
    'detail_link': 'a[1]/attribute::href'
}

SOUVENIR_MAPPING = {
    'title': '//*[@id="ctl00_ContentBody_SouvenirDisplayControl1_uxTitle"]//text()',
    'image': '//*[@id="ctl00_ContentBody_SouvenirDisplayControl1_uxLargeImage"]/attribute::src',
    'artist': '//*[@id="ctl00_ContentBody_SouvenirDisplayControl1_uxArtistNameWrapper"]/text()',
    'about_artist': '//*[@id="ctl00_ContentBody_SouvenirDisplayControl1_uxAboutTheArtist"]//text()',
    'additional_information': '//*[@id="ctl00_ContentBody_SouvenirDisplayControl1_uxInformation"]//text()'
}



from scrapy.crawler import CrawlerProcess
from scrapy.utils.project import get_project_settings

from geocrawl.spiders.geo_spider import (
    GeocachingSpider,
    ShortGeocachingSpider,
    ShortSouvenirGeocachingSpider,
    SouvenirGeocachingSpider
)


def print_item(item, response, spider):
    print(item)


def print_item_title(item, response, spider):
    print(item['title'])


def return_item_title(item, response, spider):
    return item['title']


def get_all(**kwargs):
    process = CrawlerProcess(get_project_settings())
    process.crawl(GeocachingSpider, **kwargs)
    process.start()


def get_short_caches(**kwargs):
    process = CrawlerProcess(get_project_settings())
    process.crawl(ShortGeocachingSpider, **kwargs)
    process.start()


def get_short_souvenirs(**kwargs):
    process = CrawlerProcess(get_project_settings())
    process.crawl(ShortSouvenirGeocachingSpider, **kwargs)
    process.start()


def get_souvenirs(**kwargs):
    process = CrawlerProcess(get_project_settings())
    process.crawl(SouvenirGeocachingSpider, **kwargs)
    process.start()


if __name__ == '__main__':
    # get_all(on_item_scraped=print_item_title)
    # get_short_caches(on_item_scraped=print_item_title)
    # get_short_souvenirs(on_item_scraped=print_item_title)
    get_souvenirs(on_item_scraped=print_item_title)



import pytest

from geocrawl.runner import return_item_title


class TestPrint(object):

    @pytest.fixture
    def item(self):
        return {
            'title': 'test title',
            'attribute': 'value'
        }

    def test_return_item_title(self, item):
        assert return_item_title(item, None, None) == item['title']



# -*- coding: utf-8 -*-
import os

BOT_NAME = 'geocrawl'

SPIDER_MODULES = ['geocrawl.spiders']
NEWSPIDER_MODULE = 'geocrawl.spiders'

USER_AGENT = 'Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1)'

ROBOTSTXT_OBEY = True

CONCURRENT_REQUESTS = 32

LOG_STDOUT = False

GC_USERNAME = os.environ.get('GC_USERNAME')
GC_PASSWORD = os.environ.get('GC_PASSWORD')



from distutils.core import setup

VERSION = '0.2'

setup(
    name='geocrawl',
    packages=['geocrawl'],
    version=VERSION,
    license='MIT',
    description='A library to stream geocaching related entities from the official website',
    author='Kristian Scholze',
    author_email='Scholze.Kristian@gmail.com',
    url='https://github.com/nalch/geo-crawl',
    download_url='https://github.com/nalch/geo-crawl/archive/{}.tar.gz'.format(VERSION),
    keywords=['scrapy', 'geocaching', 'cache'],
    classifiers=[],
)



STARTURL = 'https://www.geocaching.com/account/login?returnUrl='
LOGS_URL = 'https%3A%2F%2Fwww.geocaching.com%2Fmy%2Flogs.aspx%3Fs%3D1'
SOUVENIR_URL = 'https%3A%2F%2Fwww.geocaching.com%2Fmy%2Fsouvenirs.aspx'
